Renaming ContactsContract.Contacts to ContactsContract.RawContacts
diff --git a/core/java/android/provider/ContactsContract.java b/core/java/android/provider/ContactsContract.java
index da1e9dc..70c7e63 100644
--- a/core/java/android/provider/ContactsContract.java
+++ b/core/java/android/provider/ContactsContract.java
@@ -315,7 +315,7 @@
 
     }
 
-    private interface ContactsColumns {
+    private interface RawContactsColumns {
         /**
          * A reference to the {@link Aggregates#_ID} that this data belongs to.
          * <P>Type: INTEGER</P>
@@ -323,7 +323,7 @@
         public static final String AGGREGATE_ID = "aggregate_id";
 
         /**
          * Flag indicating that this {@link Contacts} entry and its children has
          * been restricted to specific platform apps.
          * <P>Type: INTEGER (boolean)</P>
          *
@@ -339,14 +339,17 @@
     }
 
     /**
-     * Constants for the contacts table, which contains the base contact information.
+     * Constants for the raw_contacts table, which contains the base contact
+     * information per sync source. Sync adapters and contact management apps
+     * are the primary consumers of this API.
      */
-    public static final class Contacts implements BaseColumns, ContactsColumns, SyncColumns,
-            ContactOptionsColumns {
+    // TODO make final as soon as renaming is complete
+    public static /*final*/ class RawContacts implements BaseColumns, RawContactsColumns,
+            SyncColumns, ContactOptionsColumns {
         /**
          * This utility class cannot be instantiated
          */
-        private Contacts() {
+        private RawContacts() {
         }
 
         /**
@@ -411,6 +414,13 @@
         }
     }
 
+    /**
+     * TODO remove as soon as full renaming is complete.
+     */
+    @Deprecated
+    public static final class Contacts extends RawContacts {
+    }
+
     private interface DataColumns {
         /**
          * The package name to use when creating {@link Resources} objects for
@@ -323,7 +323,7 @@
 
         /**
-         * Flag indicating that this {@link Contacts} entry and its children has
+         * Flag indicating that this {@link RawContacts} entry and its children has
          * been restricted to specific platform apps.
          * <P>Type: INTEGER (boolean)</P>